@@ -1,7 +1,7 @@
 from aerosandbox.geometry.common import *
 from aerosandbox.tools.airfoil_fitter.airfoil_fitter import AirfoilFitter
 from scipy.interpolate import interp1d
-
+import re
 
 class Airfoil:
     def __init__(self,
@@ -148,16 +148,26 @@ class Airfoil:
             with importlib.resources.open_text(airfoil_database, name + '.dat') as f:
                 raw_text = f.readlines()
 
-        trimmed_text = []
+        raw_coordinates = []
+        def is_number(s): # determines whether a string is representable as a float
+            try:
+                float(s)
+            except ValueError:
+                return False
+            return True
+
         for line in raw_text:
             try:
-                line_np = np.fromstring(line, sep=" ")
-                if line_np.shape[0] == 2:
-                    trimmed_text.append(line_np)
+                line_split = re.split('[; |, |\*|\n]', line)
+                line_items = [s for s in line_split
+                              if s != "" and is_number(s)
+                              ]
+                if len(line_items) == 2:
+                    raw_coordinates.append(line_items)
             except:
                 pass
 
-        coordinates = np.hstack(trimmed_text).reshape((-1, 2))
+        coordinates = np.array(raw_coordinates, dtype=float)
         self.coordinates = coordinates
 
     def populate_coordinates_from_filepath(self, filepath):
@@ -309,8 +319,8 @@ class Airfoil:
         :param backend: Which backend should we use? "plotly" or "matplotlib" [boolean]
         :return: None
         """
-        x = np.array(self.coordinates[:, 0]).reshape(-1)
-        y = np.array(self.coordinates[:, 1]).reshape(-1)
+        x = np.array(self.x()).reshape(-1)
+        y = np.array(self.y()).reshape(-1)
         if backend == "plotly":
             fig = go.Figure()
             fig.add_trace(
@@ -369,6 +379,20 @@ class Airfoil:
         # Includes the leading edge point; be careful about duplicates if using this method in conjunction with self.lower_coordinates().
         return self.coordinates[:self.LE_index() + 1, :]
 
+    def x(self):
+        """
+        Returns the x coordinates of the airfoil. Equivalent to Airfoil.coordinates[:,0].
+        :return: X coordinates as a vector
+        """
+        return self.coordinates[:, 0]
+
+    def y(self):
+        """
+        Returns the y coordinates of the airfoil. Equivalent to Airfoil.coordinates[:,1].
+        :return: Y coordinates as a vector
+        """
+        return self.coordinates[:, 1]
+
     def TE_thickness(self):
         # Returns the thickness of the trailing edge of the airfoil, in nondimensional (chord-normalized) units.
         return self.local_thickness(x_over_c=1)
@@ -385,8 +409,8 @@ class Airfoil:
 
     def area(self):
         # Returns the area of the airfoil, in nondimensional (normalized to chord^2) units.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -398,8 +422,8 @@ class Airfoil:
 
     def centroid(self):
         # Returns the centroid of the airfoil, in nondimensional (chord-normalized) units.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -415,8 +439,8 @@ class Airfoil:
 
     def Ixx(self):
         # Returns the nondimensionalized Ixx moment of inertia, taken about the centroid.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -436,8 +460,8 @@ class Airfoil:
 
     def Iyy(self):
         # Returns the nondimensionalized Iyy moment of inertia, taken about the centroid.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -457,8 +481,8 @@ class Airfoil:
 
     def Ixy(self):
         # Returns the nondimensionalized product of inertia, taken about the centroid.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -478,8 +502,8 @@ class Airfoil:
 
     def J(self):
         # Returns the nondimensionalized polar moment of inertia, taken about the centroid.
-        x = self.coordinates[:, 0]
-        y = self.coordinates[:, 1]
+        x = self.x()
+        y = self.y()
         x_n = np.roll(x, -1)  # x_next, or x_i+1
         y_n = np.roll(y, -1)  # y_next, or y_i+1
 
@@ -650,8 +674,8 @@ class Airfoil:
 
         def run():
             xf.airfoil = xfoil_model.Airfoil(
-                x=np.array(self.coordinates[:, 0]).reshape(-1),
-                y=np.array(self.coordinates[:, 1]).reshape(-1),
+                x=np.array(self.x()).reshape(-1),
+                y=np.array(self.y()).reshape(-1),
             )
             xf.Re = Re
             xf.M = M
@@ -716,8 +740,8 @@ class Airfoil:
 
         def run():
             xf.airfoil = xfoil_model.Airfoil(
-                x=np.array(self.coordinates[:, 0]).reshape(-1),
-                y=np.array(self.coordinates[:, 1]).reshape(-1),
+                x=np.array(self.x()).reshape(-1),
+                y=np.array(self.y()).reshape(-1),
             )
             xf.Re = Re
             xf.M = M
@@ -787,8 +811,8 @@ class Airfoil:
 
         def run():
             xf.airfoil = xfoil_model.Airfoil(
-                x=np.array(self.coordinates[:, 0]).reshape(-1),
-                y=np.array(self.coordinates[:, 1]).reshape(-1),
+                x=np.array(self.x()).reshape(-1),
+                y=np.array(self.y()).reshape(-1),
             )
             xf.Re = Re
             xf.M = M
@@ -856,8 +880,8 @@ class Airfoil:
 
         def run():
             xf.airfoil = xfoil_model.Airfoil(
-                x=np.array(self.coordinates[:, 0]).reshape(-1),
-                y=np.array(self.coordinates[:, 1]).reshape(-1),
+                x=np.array(self.x()).reshape(-1),
+                y=np.array(self.y()).reshape(-1),
             )
             xf.Re = Re
             xf.M = M
