@@ -1,4 +1,5 @@
 from aerosandbox.geometry.common import *
+from typing import List
 
 
 class Wing(AeroSandboxObject):
@@ -9,14 +10,14 @@ class Wing(AeroSandboxObject):
     """
 
     def __init__(self,
-                 name="Untitled Wing",  # It can help when debugging to give each wing a sensible name.
-                 x_le=0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
-                 y_le=0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
-                 z_le=0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
-                 xsecs=[],  # This should be a list of WingXSec objects.
-                 symmetric=False,  # Is the wing symmetric across the XZ plane?
-                 chordwise_panels=8,  # The number of chordwise panels to be used in VLM and panel analyses.
-                 chordwise_spacing="cosine",  # Can be 'cosine' or 'uniform'. Highly recommended to be cosine.
+                 name: str = "Untitled Wing",  # It can help when debugging to give each wing a sensible name.
+                 x_le: float = 0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
+                 y_le: float = 0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
+                 z_le: float = 0,  # Will translate all of the xsecs of the wing. Useful for moving the wing around.
+                 xsecs: List['WingXSec'] = [],  # This should be a list of WingXSec objects.
+                 symmetric: bool = False,  # Is the wing symmetric across the XZ plane?
+                 chordwise_panels: int = 8,  # The number of chordwise panels to be used in VLM and panel analyses.
+                 chordwise_spacing: str = "cosine",  # Can be 'cosine' or 'uniform'. Highly recommended to be cosine.
                  ):
         self.name = name
         self.xyz_le = cas.vertcat(x_le, y_le, z_le)
@@ -25,7 +26,7 @@ class Wing(AeroSandboxObject):
         self.chordwise_panels = chordwise_panels
         self.chordwise_spacing = chordwise_spacing
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "Wing %s (%i xsecs, %s)" % (
             self.name,
             len(self.xsecs),
@@ -33,8 +34,8 @@ class Wing(AeroSandboxObject):
         )
 
     def area(self,
-             type="wetted"
-             ):
+             type: str = "wetted"
+             ) -> float:
         """
         Returns the area, with options for various ways of measuring this.
          * wetted: wetted area
@@ -74,8 +75,8 @@ class Wing(AeroSandboxObject):
         return area
 
     def span(self,
-             type="wetted"
-             ):
+             type: str = "wetted"
+             ) -> float:
         """
         Returns the span, with options for various ways of measuring this.
          * wetted: Adds up YZ-distances of each section piece by piece
@@ -130,26 +131,92 @@ class Wing(AeroSandboxObject):
             span *= 2
         return span
 
-    def aspect_ratio(self):
+    def aspect_ratio(self) -> float:
         # Returns the aspect ratio (b^2/S).
         # Uses the full span and the full area if symmetric.
         return self.span() ** 2 / self.area()
 
-    def has_symmetric_control_surfaces(self):
+    def has_symmetric_control_surfaces(self) -> bool:
         # Returns a boolean of whether the wing is totally symmetric (i.e.), every xsec has control_surface_type = "symmetric".
         for xsec in self.xsecs:
             if not xsec.control_surface_type == "symmetric":
                 return False
         return True
 
-    def mean_geometric_chord(self):
+    def mean_geometric_chord(self) -> float:
         """
         Returns the mean geometric chord of the wing (S/b).
         :return:
         """
         return self.area() / self.span()
 
-    def mean_twist_angle(self):
+    def mean_aerodynamic_chord(self) -> float:
+        """
+        Returns the mean aerodynamic chord of the wing.
+        """
+        area = 0
+        sum_dMAC_dA = 0
+
+        for i, xsec_a in enumerate(self.xsecs[:-1]):
+            xsec_b = self.xsecs[i + 1]
+
+            section_span = cas.sqrt(
+                cas.sumsqr(xsec_a.quarter_chord()[1:, :] - xsec_b.quarter_chord()[1:, :])
+            )
+
+            section_taper_ratio = xsec_b.chord / xsec_a.chord
+            section_area = (xsec_a.chord + xsec_b.chord) / 2 * section_span
+            section_MAC = (2 / 3) * xsec_a.chord * (
+                    (1 + section_taper_ratio + section_taper_ratio ** 2) /
+                    (1 + section_taper_ratio)
+            )
+            area = area + section_area
+            sum_dMAC_dA = sum_dMAC_dA + section_area * section_MAC
+
+        MAC = sum_dMAC_dA / area
+
+        return MAC
+
+    # def mean_aerodynamic_chord_location(self): # TODO verify and add
+    #     """
+    #     Returns the x and y LE position of the mean aerodynamic chord.
+    #     Based on the same assumptions as wing.mean_aerodynamic_chord.
+    #     """
+    #     area = 0
+    #     sum_dx_dA = 0
+    #     sum_dy_dA = 0
+    #     sum_dz_dA = 0
+    #
+    #     for i, xsec_a in enumerate(self.xsecs[:-1]):
+    #         xsec_b = self.xsecs[i + 1]
+    #
+    #         c_r = xsec_a.chord
+    #         c_t = xsec_b.chord
+    #         x_r = xsec_a.x_le
+    #         x_t = xsec_b.x_le
+    #         y_r = xsec_a.y_le
+    #         y_t = xsec_b.y_le
+    #         z_r = xsec_a.z_le
+    #         z_t = xsec_b.z_le
+    #
+    #         taper_ratio = c_t / c_r
+    #         d_area = (c_r + c_t) * (y_t - y_r) / 2
+    #         area = area + d_area
+    #
+    #         x_mac = x_r + (x_t - x_r) * (1 + 2 * taper_ratio) / (3 + 3 * taper_ratio)
+    #         sum_dx_dA = d_area * x_mac + sum_dx_dA
+    #         y_mac = y_r + (y_t - y_r) * (1 + 2 * taper_ratio) / (3 + 3 * taper_ratio)
+    #         sum_dy_dA = d_area * y_mac + sum_dy_dA
+    #         z_mac = z_r + (z_t - z_r) * (1 + 2 * taper_ratio) / (3 + 3 * taper_ratio)
+    #         sum_dz_dA = d_area * z_mac + sum_dz_dA
+    #
+    #     x_mac = sum_dx_dA / area
+    #     y_mac = sum_dy_dA / area
+    #     z_mac = sum_dz_dA / area
+    #
+    #     return cas.vertcat(x_mac, y_mac, z_mac)
+
+    def mean_twist_angle(self) -> float:
         """
         Returns the mean twist angle (in degrees) of the wing, weighted by span.
         You can think of it as \int_{b}(twist)db, where b is span.
@@ -188,7 +255,7 @@ class Wing(AeroSandboxObject):
         mean_twist = twist_span_product / cas.sum1(cas.vertcat(*span))
         return mean_twist
 
-    def mean_sweep_angle(self):
+    def mean_sweep_angle(self) -> float:
         """
         Returns the mean quarter-chord sweep angle (in degrees) of the wing, relative to the x-axis.
         Positive sweep is backwards, negative sweep is forward.
@@ -206,7 +273,7 @@ class Wing(AeroSandboxObject):
 
         return sweep_deg
 
-    def approximate_center_of_pressure(self):
+    def approximate_center_of_pressure(self) -> cas.DM:
         """
         Returns the approximate location of the center of pressure. Given as the area-weighted quarter chord of the wing.
         :return: [x, y, z] of the approximate center of pressure
@@ -250,6 +317,16 @@ class Wing(AeroSandboxObject):
 
         return approximate_cop
 
+    def taper_ratio(self) -> float:
+        """
+        Gives the taper ratio of the Wing. Strictly speaking, only valid for trapezoidal wings.
+
+        Returns:
+            Taper ratio of the Wing.
+
+        """
+        return self.xsecs[-1].chord / self.xsecs[0].chord
+
 
 class WingXSec(AeroSandboxObject):
     """
@@ -257,21 +334,22 @@ class WingXSec(AeroSandboxObject):
     """
 
     def __init__(self,
-                 x_le=0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
-                 y_le=0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
-                 z_le=0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
-                 chord=0,  # Chord of the wing at this cross section
-                 twist=0,  # Twist always occurs about the leading edge!
-                 twist_axis=cas.DM([0, 1, 0]),  # By default, always twists about the Y-axis.
-                 airfoil=None,  # type: Airfoil # The airfoil to be used at this cross section.
-                 control_surface_type="symmetric",
+                 x_le: float = 0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
+                 y_le: float = 0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
+                 z_le: float = 0,  # Coordinate of the leading edge of the cross section, relative to the wing's datum.
+                 chord: float = 0,  # Chord of the wing at this cross section
+                 twist: float = 0,  # Twist always occurs about the leading edge!
+                 twist_axis: cas.DM = cas.DM([0, 1, 0]),  # By default, always twists about the Y-axis.
+                 airfoil: 'Airfoil' = None,  # The airfoil to be used at this cross section.
+                 control_surface_type: str = "symmetric",  # TODO change this to a boolean
                  # Can be "symmetric" or "asymmetric". Symmetric is like flaps, asymmetric is like an aileron.
-                 control_surface_hinge_point=0.75,  # The location of the control surface hinge, as a fraction of chord.
+                 control_surface_hinge_point: float = 0.75,
+                 # The location of the control surface hinge, as a fraction of chord.
                  # Point at which the control surface is applied, as a fraction of chord.
-                 control_surface_deflection=0,  # Control deflection, in degrees. Downwards-positive.
-                 spanwise_panels=8,
+                 control_surface_deflection: float = 0,  # Control deflection, in degrees. Downwards-positive.
+                 spanwise_panels: int = 8,
                  # The number of spanwise panels to be used between this cross section and the next one.
-                 spanwise_spacing="cosine"  # Can be 'cosine' or 'uniform'. Highly recommended to be cosine.
+                 spanwise_spacing: str = "cosine"  # Can be 'cosine' or 'uniform'. Highly recommended to be cosine.
                  ):
         if airfoil is None:
             raise ValueError("'airfoil' argument missing! (Needs an object of Airfoil type)")
@@ -292,22 +370,23 @@ class WingXSec(AeroSandboxObject):
 
         self.xyz_le = cas.vertcat(x_le, y_le, z_le)
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "WingXSec (airfoil = %s, chord = %f, twist = %f)" % (
             self.airfoil.name,
             self.chord,
             self.twist
         )
 
-    def xyz_te(self):
+    def quarter_chord(self) -> cas.DM:
+        """
+        Returns the (wing-relative) coordinates of the quarter chord of the cross section.
+        """
+        return 0.75 * self.xyz_le + 0.25 * self.xyz_te()
+
+    def xyz_te(self) -> cas.DM:
         """
         Returns the (wing-relative) coordinates of the trailing edge of the cross section.
         """
         rot = angle_axis_rotation_matrix(self.twist * cas.pi / 180, self.twist_axis)
         xyz_te = self.xyz_le + rot @ cas.vertcat(self.chord, 0, 0)
-        # xyz_te = self.xyz_le + self.chord * cas.vertcat(
-        #     cas.cos(self.twist * cas.pi / 180),
-        #     0,
-        #     -cas.sin(self.twist * cas.pi / 180)
-        # )
         return xyz_te
